"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryPosts = exports.getPostBySlug = exports.getPost = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const float_1 = require("@wix/sdk-runtime/transformations/float");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressNpmCommunitiesForumApiPostManagementServiceUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/_internal/communities',
                destPath: '',
            },
        ],
        'apps._base_domain_': [
            {
                srcPath: '/communities-forum-app',
                destPath: '',
            },
            {
                srcPath: '/communities',
                destPath: '',
            },
            {
                srcPath: '/_api/',
                destPath: '/_api',
            },
        ],
        'forums.wixapps.net': [
            {
                srcPath: '',
                destPath: '',
            },
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        'forums._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '',
                destPath: '',
            },
            {
                srcPath: '/forum/v1/draft-posts',
                destPath: '/v1/draft-posts',
            },
            {
                srcPath: '/forum/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/forum/v1/comments',
                destPath: '/v1/comments',
            },
            {
                srcPath: '/forum/v1/posts',
                destPath: '/v1/posts',
            },
        ],
        _: [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities-forum-app',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/forums/this',
                destPath: '/_api/forums/this',
            },
            {
                srcPath: '/_api/communities/categories',
                destPath: '/_api/categories',
            },
            {
                srcPath: '/_api/communities/posts',
                destPath: '/_api/posts',
            },
            {
                srcPath: '/_api/communities/platformized/v1/draft-posts',
                destPath: '/v1/draft-posts',
            },
            {
                srcPath: '/_api/communities/platformized/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/communities/platformized/v1/comments',
                destPath: '/v1/comments',
            },
            {
                srcPath: '/_api/communities/platformized/v1/posts',
                destPath: '/v1/posts',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        '*.pub.wix-code.com': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1',
                destPath: '/v1',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
            {
                srcPath: '/_api/communities/platformized/v1/posts',
                destPath: '/v1/posts',
            },
        ],
        'bo._base_domain_': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'notifications-app.wixapps.net': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/_api/communities',
                destPath: '/_api',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/forum/v1/notifications',
                destPath: '/v1/notifications',
            },
            {
                srcPath: '/forum/v1/draft-posts',
                destPath: '/v1/draft-posts',
            },
            {
                srcPath: '/forum/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/forum/v1/comments',
                destPath: '/v1/comments',
            },
            {
                srcPath: '/forum/v1/posts',
                destPath: '/v1/posts',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_forum_posts';
/**
 * Retrieves a single post by ID.
 * @deprecated Will be removed on 2025-04-15.
 */
function getPost(payload) {
    function __getPost({ host }) {
        const metadata = {
            entityFqdn: 'wix.forum.v1.post',
            method: 'GET',
            methodFqn: 'com.wixpress.npm.communities.forum.api.PostManagementService.GetPost',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressNpmCommunitiesForumApiPostManagementServiceUrl({
                protoPath: '/v1/posts/{postId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'post.createdDate' },
                        { path: 'post.lastActivityDate' },
                        { path: 'post.updatedDate' },
                        { path: 'post.images.urlExpirationDate' },
                        { path: 'post.videos.urlExpirationDate' },
                        { path: 'post.videos.resolutions.urlExpirationDate' },
                        { path: 'post.videos.resolutions.poster.urlExpirationDate' },
                        { path: 'post.videos.posters.urlExpirationDate' },
                    ],
                },
                {
                    transformFn: float_1.transformRESTFloatToSDKFloat,
                    paths: [
                        { path: 'post.images.focalPoint.x' },
                        { path: 'post.images.focalPoint.y' },
                        { path: 'post.videos.resolutions.poster.focalPoint.x' },
                        { path: 'post.videos.resolutions.poster.focalPoint.y' },
                        { path: 'post.videos.posters.focalPoint.x' },
                        { path: 'post.videos.posters.focalPoint.y' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getPost;
}
exports.getPost = getPost;
/**
 * Retrieves a single post by URL slug.
 * @deprecated Will be removed on 2025-04-15.
 */
function getPostBySlug(payload) {
    function __getPostBySlug({ host }) {
        const metadata = {
            entityFqdn: 'wix.forum.v1.post',
            method: 'GET',
            methodFqn: 'com.wixpress.npm.communities.forum.api.PostManagementService.GetPostBySlug',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressNpmCommunitiesForumApiPostManagementServiceUrl({
                protoPath: '/v1/posts/slugs/{slug}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'post.createdDate' },
                        { path: 'post.lastActivityDate' },
                        { path: 'post.updatedDate' },
                        { path: 'post.images.urlExpirationDate' },
                        { path: 'post.videos.urlExpirationDate' },
                        { path: 'post.videos.resolutions.urlExpirationDate' },
                        { path: 'post.videos.resolutions.poster.urlExpirationDate' },
                        { path: 'post.videos.posters.urlExpirationDate' },
                    ],
                },
                {
                    transformFn: float_1.transformRESTFloatToSDKFloat,
                    paths: [
                        { path: 'post.images.focalPoint.x' },
                        { path: 'post.images.focalPoint.y' },
                        { path: 'post.videos.resolutions.poster.focalPoint.x' },
                        { path: 'post.videos.resolutions.poster.focalPoint.y' },
                        { path: 'post.videos.posters.focalPoint.x' },
                        { path: 'post.videos.posters.focalPoint.y' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getPostBySlug;
}
exports.getPostBySlug = getPostBySlug;
/**
 * Returns a list of posts by query.
 *
 * Paging
 * - limit: default - 10, min - 0, max - 100
 * - offset: default - 0, min - 0
 *
 * Filterable fields:
 * - id
 * - categoryId
 * - ownerId
 * - title
 * - contentText
 * - bestAnswerCommentId
 * - pinned
 * - commentingEnabled
 * - commentCount
 * - likeCount
 * - viewCount
 * - createdDate
 * - editedDate
 * - lastActivityDate
 * - slug
 *
 * Sortable fields:
 * - lastActivityDate
 * - createdDate
 * - commentCount
 * - viewCount
 * - likeCount
 * - pinned
 * @deprecated Will be removed on 2025-10-15.
 */
function queryPosts(payload) {
    function __queryPosts({ host }) {
        const metadata = {
            entityFqdn: 'wix.forum.v1.post',
            method: 'POST',
            methodFqn: 'com.wixpress.npm.communities.forum.api.PostManagementService.QueryPosts',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressNpmCommunitiesForumApiPostManagementServiceUrl({
                protoPath: '/v1/posts/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'posts.createdDate' },
                        { path: 'posts.lastActivityDate' },
                        { path: 'posts.updatedDate' },
                        { path: 'posts.images.urlExpirationDate' },
                        { path: 'posts.videos.urlExpirationDate' },
                        { path: 'posts.videos.resolutions.urlExpirationDate' },
                        { path: 'posts.videos.resolutions.poster.urlExpirationDate' },
                        { path: 'posts.videos.posters.urlExpirationDate' },
                    ],
                },
                {
                    transformFn: float_1.transformRESTFloatToSDKFloat,
                    paths: [
                        { path: 'posts.images.focalPoint.x' },
                        { path: 'posts.images.focalPoint.y' },
                        { path: 'posts.videos.resolutions.poster.focalPoint.x' },
                        { path: 'posts.videos.resolutions.poster.focalPoint.y' },
                        { path: 'posts.videos.posters.focalPoint.x' },
                        { path: 'posts.videos.posters.focalPoint.y' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryPosts;
}
exports.queryPosts = queryPosts;
//# sourceMappingURL=forum-v1-post-posts.http.js.map