import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { GetPostBySlugOptions, GetPostOptions, Post, PostClosedEnvelope, PostCreatedEnvelope, PostDeletedEnvelope, PostLikedEnvelope, PostMovedEnvelope, PostOpenedEnvelope, PostPinnedEnvelope, PostReactedEnvelope, PostReportedEnvelope, PostResponse, PostUnlikedEnvelope, PostUnpinnedEnvelope, PostUnreactedEnvelope, PostUpdatedEnvelope, QueryPostsOptions, QueryPostsResponse } from './forum-v1-post-posts.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function getPost(httpClient: HttpClient): GetPostSignature;
interface GetPostSignature {
    /**
     * Retrieves a single post by ID.
     * @param - Post ID.
     * @param - Options specifying which additional fields to return.
     * @returns Post for the provided post ID.
     * @deprecated
     */
    (postId: string, options?: GetPostOptions | undefined): Promise<Post>;
}
export declare function getPostBySlug(httpClient: HttpClient): GetPostBySlugSignature;
interface GetPostBySlugSignature {
    /**
     * Retrieves a single post by URL slug.
     * @param - URL slug.
     * @param - Options specifying which additional fields to return.
     * @deprecated
     */
    (slug: string, options?: GetPostBySlugOptions | undefined): Promise<PostResponse>;
}
export declare function queryPosts(httpClient: HttpClient): QueryPostsSignature;
interface QueryPostsSignature {
    /**
     * Returns a list of posts by query.
     *
     * Paging
     * - limit: default - 10, min - 0, max - 100
     * - offset: default - 0, min - 0
     *
     * Filterable fields:
     * - id
     * - categoryId
     * - ownerId
     * - title
     * - contentText
     * - bestAnswerCommentId
     * - pinned
     * - commentingEnabled
     * - commentCount
     * - likeCount
     * - viewCount
     * - createdDate
     * - editedDate
     * - lastActivityDate
     * - slug
     *
     * Sortable fields:
     * - lastActivityDate
     * - createdDate
     * - commentCount
     * - viewCount
     * - likeCount
     * - pinned
     * @param - Options for sorting, filtering, paging, and specifying return fields.
     * @deprecated
     */
    (options?: QueryPostsOptions | undefined): Promise<QueryPostsResponse>;
}
export declare const onPostClosed: EventDefinition<PostClosedEnvelope, "wix.forum.post_closed">;
export declare const onPostCreated: EventDefinition<PostCreatedEnvelope, "wix.forum.post_created">;
export declare const onPostDeleted: EventDefinition<PostDeletedEnvelope, "wix.forum.post_deleted">;
export declare const onPostLiked: EventDefinition<PostLikedEnvelope, "wix.forum.post_liked">;
export declare const onPostMoved: EventDefinition<PostMovedEnvelope, "wix.forum.post_moved">;
export declare const onPostOpened: EventDefinition<PostOpenedEnvelope, "wix.forum.post_opened">;
export declare const onPostPinned: EventDefinition<PostPinnedEnvelope, "wix.forum.post_pinned">;
export declare const onPostReacted: EventDefinition<PostReactedEnvelope, "wix.forum.post_reacted">;
export declare const onPostReported: EventDefinition<PostReportedEnvelope, "wix.forum.post_reported">;
export declare const onPostUnliked: EventDefinition<PostUnlikedEnvelope, "wix.forum.post_unliked">;
export declare const onPostUnpinned: EventDefinition<PostUnpinnedEnvelope, "wix.forum.post_unpinned">;
export declare const onPostUnreacted: EventDefinition<PostUnreactedEnvelope, "wix.forum.post_unreacted">;
export declare const onPostUpdated: EventDefinition<PostUpdatedEnvelope, "wix.forum.post_updated">;
export { ActionEvent, AddReactionRequest, AddReactionResponse, BaseEventMetadata, Closed, CreatePostRequest, CreatePostResponse, DeletePostRequest, DeletePostResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityType, EntityUpdatedEvent, EventMetadata, Field, FocalPoint, GetPostBySlugOptions, GetPostOptions, IdentificationData, IdentificationDataIdOneOf, Identity, IdentityType, Interaction, Liked, MarkPostReadRequest, MarkPostReadResponse, MarkPostUnreadRequest, MarkPostUnreadResponse, MarkPostsSeenRequest, MarkPostsSeenResponse, MessageEnvelope, Moved, Opened, Order, PinPostRequest, PinPostResponse, Pinned, Post, PostClosedEnvelope, PostCreatedEnvelope, PostDeletedEnvelope, PostFieldField, PostLikedEnvelope, PostMovedEnvelope, PostOpenedEnvelope, PostPinnedEnvelope, PostReactedEnvelope, PostReportedEnvelope, PostRequest, PostResponse, PostSlugRequest, PostType, PostUnlikedEnvelope, PostUnpinnedEnvelope, PostUnreactedEnvelope, PostUpdatedEnvelope, PostsPaging, PostsSort, QueryPostsOptions, QueryPostsRequest, QueryPostsResponse, QueryPostsResponseMetaData, Reacted, ReactionCodeCount, ReactionIdentity, RecentActivity, RecentActivityInitiatorOneOf, RemoveBestAnswerRequest, RemoveBestAnswerResponse, RemoveReactionRequest, RemoveReactionResponse, ReportPostRequest, ReportPostResponse, ReportType, Reported, RestoreInfo, SetBestAnswerRequest, SetBestAnswerResponse, Unliked, UnpinPostRequest, UnpinPostResponse, Unpinned, Unreacted, UpdatePostRequest, UpdatePostResponse, VideoResolution, ViewPostRequest, ViewPostResponse, WebhookIdentityType, } from './forum-v1-post-posts.universal.js';
