import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTImageToSDKImage } from '@wix/sdk-runtime/transformations/image';
import { transformRESTPageURLToSDKPageURL } from '@wix/sdk-runtime/transformations/page-url';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { transformRESTVideoV2ToSDKVideoV2 } from '@wix/sdk-runtime/transformations/video-v2';
import { EventDefinition } from '@wix/sdk-types';
import { getPost as universalGetPost, getPostBySlug as universalGetPostBySlug, queryPosts as universalQueryPosts, } from './forum-v1-post-posts.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/forum' };
export function getPost(httpClient) {
    return (postId, options) => universalGetPost(postId, options, 
    // @ts-ignore
    { httpClient });
}
export function getPostBySlug(httpClient) {
    return (slug, options) => universalGetPostBySlug(slug, options, 
    // @ts-ignore
    { httpClient });
}
export function queryPosts(httpClient) {
    return (options) => universalQueryPosts(options, 
    // @ts-ignore
    { httpClient });
}
export const onPostClosed = EventDefinition('wix.forum.post_closed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostCreated = EventDefinition('wix.forum.post_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.lastActivityDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'entity.url' }],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [{ path: 'entity.images', isRepeated: true }],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [{ path: 'entity.videos', isRepeated: true }],
    },
])))();
export const onPostDeleted = EventDefinition('wix.forum.post_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.createdDate' },
            { path: 'undefined.lastActivityDate' },
            { path: 'undefined.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'undefined.url' }],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [{ path: 'undefined.images', isRepeated: true }],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [{ path: 'undefined.videos', isRepeated: true }],
    },
])))();
export const onPostLiked = EventDefinition('wix.forum.post_liked', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostMoved = EventDefinition('wix.forum.post_moved', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostOpened = EventDefinition('wix.forum.post_opened', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostPinned = EventDefinition('wix.forum.post_pinned', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostReacted = EventDefinition('wix.forum.post_reacted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostReported = EventDefinition('wix.forum.post_reported', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostUnliked = EventDefinition('wix.forum.post_unliked', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostUnpinned = EventDefinition('wix.forum.post_unpinned', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostUnreacted = EventDefinition('wix.forum.post_unreacted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onPostUpdated = EventDefinition('wix.forum.post_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.lastActivityDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'entity.url' }],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [{ path: 'entity.images', isRepeated: true }],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [{ path: 'entity.videos', isRepeated: true }],
    },
])))();
export { EntityType, Field, IdentityType, Interaction, Order, PostFieldField, PostType, ReportType, WebhookIdentityType, } from './forum-v1-post-posts.universal.js';
//# sourceMappingURL=forum-v1-post-posts.public.js.map